menuItemBuilder property
Function that builds the option Widget shown in the menu
Implementation
final OptionBuilder<DropdownMenuButtonOptions>? menuItemBuilder;
Function that builds the option Widget shown in the menu
final OptionBuilder<DropdownMenuButtonOptions>? menuItemBuilder;