DropdownBodyBox class
- Annotations
Constructors
- DropdownBodyBox({required double itemExtent, required BoxInfo boxInfo, Widget containerBuilder({required Widget bodyList, required DropdownBodyBox dropdownBodyBox})?})
-
const
Properties
- boxInfo → BoxInfo
-
final
- containerBuilder → Widget Function({required Widget bodyList, required DropdownBodyBox dropdownBodyBox})?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemExtent → double
-
Used by SliverFixedExtentList in the dropdown menu
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? itemExtent, BoxInfo? boxInfo}) → DropdownBodyBox -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited